@@ -2,7 +2,7 @@ from datetime import datetime
 
 from sqlalchemy import Column
 
-from .model_utils import TimestampField
+from ms_utils import TimestampField
 
 
 class BaseModal:
