@@ -1,13 +1,13 @@
 """
 Model Utils
 """
-import datetime
-from datetime import datetime
 import json
 from abc import ABC
 
 from sqlalchemy import TypeDecorator, Text, Integer
 
+from ms_utils import convert_date_to_timestamp, convert_timestamp_to_date
+
 
 class JsonEncodeDict(TypeDecorator, ABC):
     """
@@ -44,7 +44,7 @@ class TimestampField(TypeDecorator, ABC):
         :param dialect:
         :return:
         """
-        return value.replace(tzinfo=datetime.timezone.utc).timestamp()
+        return convert_date_to_timestamp(value)
 
     def process_result_value(self, value, dialect):
         """
@@ -52,7 +52,7 @@ class TimestampField(TypeDecorator, ABC):
         :param dialect:
         :return:
         """
-        return datetime.fromtimestamp(value)
+        return convert_timestamp_to_date(value)
 
 
 def generic_get_serialize_data(schema_object, query):
